@@ -53,18 +53,6 @@ force_imports = """
 
 import os
 import sys
-
-def force_install(module):
-    cmds = [f'pip install {module}', f'pip3 install {module}', f'python -m pip install {module}', f'python3 -m pip install {module}']
-
-    res = True
-    for cmd in cmds:
-        if not res:
-            break
-        res = os.system(cmd)
-
-force_install("requirements.txt")
-
 """
 
 def build_py(functions):
